vfbLib.parsers.truetype.TrueTypeStemPpemsParser
===============================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: TrueTypeStemPpemsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrueTypeStemPpemsParser.__init__
      ~TrueTypeStemPpemsParser.parse
      ~TrueTypeStemPpemsParser.parse_hex
      ~TrueTypeStemPpemsParser.read_double
      ~TrueTypeStemPpemsParser.read_doubles
      ~TrueTypeStemPpemsParser.read_float
      ~TrueTypeStemPpemsParser.read_floats
      ~TrueTypeStemPpemsParser.read_int16
      ~TrueTypeStemPpemsParser.read_int32
      ~TrueTypeStemPpemsParser.read_int8
      ~TrueTypeStemPpemsParser.read_str
      ~TrueTypeStemPpemsParser.read_str_all
      ~TrueTypeStemPpemsParser.read_uint16
      ~TrueTypeStemPpemsParser.read_uint32
      ~TrueTypeStemPpemsParser.read_uint8
      ~TrueTypeStemPpemsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrueTypeStemPpemsParser.encoding
      ~TrueTypeStemPpemsParser.master_count
      ~TrueTypeStemPpemsParser.stream
      ~TrueTypeStemPpemsParser.ttStemsH_count
      ~TrueTypeStemPpemsParser.ttStemsV_count
   
   